==> hybrid-0.0.3.tar.gz: lib/pages/hybrid/container.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:dva_flutter/connector.dart';
import 'package:dva_dart/dva_dart.dart' as Dva;

import '../../models/states.dart';
import 'page.dart';
import 'abstracts.dart';

class DefaultLoadingPage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Text(
        "Loading",
        style: TextStyle(color: Colors.white),
      ),
    );
  }
}

Widget hybridAppContainer(
    {BuildContext context, String bundleApiUrl, String indexKey}) {
  return DvaConnector(
    context: context,
    key: Key('HybridAppPage'),
    listenTo: ['hybridApp'],
    builder: (BuildContext context, DvaModels models, dispatch) {
      /// TODO: move all non-stateLess function to model, to make AppPage stateLess
      HybridAppState hybridAppState = models.getState('hybridApp');

      if (hybridAppState.status == HybridAppStatus.Loading) {
        dispatch(Dva.createAction('hybridApp/getBundle')(
            Dva.Payload<Map<String, String>>(
                {"bundleApiUrl": bundleApiUrl, "indexKey": indexKey})));
      }

      // dispatch(Dva.createAction('dpoMiniApp/getBundle')(Dva.Payload(null)));
      if (hybridAppState.status == HybridAppStatus.Success) {
        return DpoMiniAppPage({},
            hybridAppState.pages,
            hybridAppState.handlers,
            hybridAppState.methodChannel,
            hybridAppState.basicChannel,
            hybridAppState.indexPage);
      }

      return DefaultLoadingPage();
    },
  );
}

==> hybrid-0.0.5.tar.gz: lib/pages/hybrid/container.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:dva_flutter/connector.dart';
import 'package:dva_dart/dva_dart.dart' as Dva;

import '../../models/states.dart';
import 'page.dart';

class DefaultLoadingPage extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Text(
        "Loading",
        style: TextStyle(color: Colors.white),
      ),
    );
  }
}

Widget hybridAppContainer(
    {BuildContext context, String bundleApiUrl, String indexKey}) {
  return DvaConnector(
    context: context,
    key: Key('HybridAppPage'),
    listenTo: ['hybridApp'],
    builder: (BuildContext context, DvaModels models, dispatch) {
      /// TODO: move all non-stateLess function to model, to make AppPage stateLess
      HybridAppState hybridAppState = models.getState('hybridApp');

      if (hybridAppState.status == HybridAppStatus.Loading &&
          bundleApiUrl.startsWith("http")) {
        dispatch(Dva.createAction('hybridApp/getBundle')(
            Dva.Payload<Map<String, String>>(
                {"bundleApiUrl": bundleApiUrl, "indexKey": indexKey})));
      }

      // dispatch(Dva.createAction('dpoMiniApp/getBundle')(Dva.Payload(null)));
      if (hybridAppState.status == HybridAppStatus.Success) {
        return DpoMiniAppPage({},
            hybridAppState.pages,
            hybridAppState.handlers,
            hybridAppState.methodChannel,
            hybridAppState.basicChannel,
            hybridAppState.indexPage);
      }

      return DefaultLoadingPage();
    },
  );
}
